@@ -8,7 +8,6 @@ log = logging.getLogger(__name__)
 
 
 class Xray(AtlassianRestAPI):
-
     def __init__(self, *args, **kwargs):
         super(Xray, self).__init__(*args, **kwargs)
 
@@ -19,7 +18,7 @@ class Xray(AtlassianRestAPI):
         :param test_keys: list of tests (eg. `['TEST-001', 'TEST-002']`) to retrieve.
         :return: Returns the retrieved tests.
         """
-        url = 'rest/raven/1.0/api/test/?keys={0}'.format(';'.join(test_keys))
+        url = "rest/raven/1.0/api/test/?keys={0}".format(";".join(test_keys))
         return self.get(url)
 
     def get_test_statuses(self):
@@ -27,7 +26,7 @@ class Xray(AtlassianRestAPI):
         Retrieve a list of all Test Statuses available in Xray sorted by rank.
         :return: Returns the test statuses.
         """
-        url = 'rest/raven/1.0/api/settings/teststatuses'
+        url = "rest/raven/1.0/api/settings/teststatuses"
         return self.get(url)
 
     def get_test_runs(self, test_key):
@@ -36,7 +35,7 @@ class Xray(AtlassianRestAPI):
         :param test_key: Test key (eg. 'TEST-001').
         :return: Returns the exported test runs.
         """
-        url = 'rest/raven/1.0/api/test/{0}/testruns'.format(test_key)
+        url = "rest/raven/1.0/api/test/{0}/testruns".format(test_key)
         return self.get(url)
 
     def get_test_runs_with_environment(self, test_key, test_environments):
@@ -47,8 +46,10 @@ class Xray(AtlassianRestAPI):
         :param test_environments: Test execution environments separated by ','.
         :return: Returns the exported test runs.
         """
-        env = '?testEnvironments={0}'.format(','.join([re.escape(env) for env in test_environments]))
-        url = 'rest/raven/1.0/api/test/{0}/testruns{1}'.format(test_key, env)
+        env = "?testEnvironments={0}".format(
+            ",".join([re.escape(env) for env in test_environments])
+        )
+        url = "rest/raven/1.0/api/test/{0}/testruns{1}".format(test_key, env)
         return self.get(url)
 
     def get_test_preconditions(self, test_key):
@@ -57,7 +58,7 @@ class Xray(AtlassianRestAPI):
         :param test_key: Test key (eg. 'TEST-001').
         :return: Returns the test pre-conditions of a given test.
         """
-        url = 'rest/raven/1.0/api/test/{0}/preconditions'.format(test_key)
+        url = "rest/raven/1.0/api/test/{0}/preconditions".format(test_key)
         return self.get(url)
 
     def get_test_sets(self, test_key):
@@ -66,7 +67,7 @@ class Xray(AtlassianRestAPI):
         :param test_key: Test key (eg. 'TEST-001').
         :return: Returns the exported test sets.
         """
-        url = 'rest/raven/1.0/api/test/{0}/testsets'.format(test_key)
+        url = "rest/raven/1.0/api/test/{0}/testsets".format(test_key)
         return self.get(url)
 
     def get_test_executions(self, test_key):
@@ -75,7 +76,7 @@ class Xray(AtlassianRestAPI):
         :param test_key: Test key (eg. 'TEST-001').
         :return: Returns the exported test executions.
         """
-        url = 'rest/raven/1.0/api/test/{0}/testexecutions'.format(test_key)
+        url = "rest/raven/1.0/api/test/{0}/testexecutions".format(test_key)
         return self.get(url)
 
     def get_test_plans(self, test_key):
@@ -84,7 +85,7 @@ class Xray(AtlassianRestAPI):
         :param test_key: Test key (eg. 'TEST-001').
         :return: Returns the exported test plans.
         """
-        url = 'rest/raven/1.0/api/test/{0}/testplans'.format(test_key)
+        url = "rest/raven/1.0/api/test/{0}/testplans".format(test_key)
         return self.get(url)
 
     # Test Steps API
@@ -93,7 +94,7 @@ class Xray(AtlassianRestAPI):
         Retrieve the test step statuses available in Xray sorted by rank.
         :return: Returns the test step statuses available in Xray sorted by rank.
         """
-        url = 'rest/raven/1.0/api/settings/teststepstatuses'
+        url = "rest/raven/1.0/api/settings/teststepstatuses"
         return self.get(url)
 
     def get_test_step(self, test_key, test_step_id):
@@ -103,7 +104,7 @@ class Xray(AtlassianRestAPI):
         :param test_step_id: ID of the test step.
         :return: Return the test step with the given id.
         """
-        url = 'rest/raven/1.0/api/test/{0}/step/{1}'.format(test_key, test_step_id)
+        url = "rest/raven/1.0/api/test/{0}/step/{1}".format(test_key, test_step_id)
         return self.get(url)
 
     def get_test_steps(self, test_key):
@@ -112,7 +113,7 @@ class Xray(AtlassianRestAPI):
         :param test_key: Test key (eg. 'TEST-001').
         :return: Return the test steps of a given test.
         """
-        url = 'rest/raven/1.0/api/test/{0}/step'.format(test_key)
+        url = "rest/raven/1.0/api/test/{0}/step".format(test_key)
         return self.get(url)
 
     def create_test_step(self, test_key, step, data, result):
@@ -123,10 +124,10 @@ class Xray(AtlassianRestAPI):
         :param step: Test Step name (eg. 'Example step').
         :param data: Test Step data (eg. 'Example data').
         :param result: Test Step results (eg. 'Example results').
-        :return: 
+        :return:
         """
-        create = {'step': step, 'data': data, 'result': result, 'attachments': []}
-        url = 'rest/raven/1.0/api/test/{0}/step'.format(test_key)
+        create = {"step": step, "data": data, "result": result, "attachments": []}
+        url = "rest/raven/1.0/api/test/{0}/step".format(test_key)
         return self.put(url, create)
 
     def update_test_step(self, test_key, test_step_id, step, data, result):
@@ -140,8 +141,13 @@ class Xray(AtlassianRestAPI):
         :param result: Test Step results (eg. 'Example results').
         :return:
         """
-        update = {'step': step, 'data': data, 'result': result, 'attachments': {'add': [], 'remove': []}}
-        url = 'rest/raven/1.0/api/test/{0}/step/{1}'.format(test_key, test_step_id)
+        update = {
+            "step": step,
+            "data": data,
+            "result": result,
+            "attachments": {"add": [], "remove": []},
+        }
+        url = "rest/raven/1.0/api/test/{0}/step/{1}".format(test_key, test_step_id)
         return self.post(url, update)
 
     def delete_test_step(self, test_key, test_step_id):
@@ -151,7 +157,7 @@ class Xray(AtlassianRestAPI):
         :param test_step_id: ID of the test step.
         :return:
         """
-        url = 'rest/raven/1.0/api/test/{0}/step/{1}'.format(test_key, test_step_id)
+        url = "rest/raven/1.0/api/test/{0}/step/{1}".format(test_key, test_step_id)
         return self.delete(url)
 
     # Pre-Conditions API
@@ -161,7 +167,7 @@ class Xray(AtlassianRestAPI):
         :param precondition_key: Precondition key (eg. 'TEST-001').
         :return: Return a list of the test associated with the pre-condition.
         """
-        url = 'rest/raven/1.0/api/precondition/{0}/test'.format(precondition_key)
+        url = "rest/raven/1.0/api/precondition/{0}/test".format(precondition_key)
         return self.get(url)
 
     def update_precondition(self, precondition_key, add=None, remove=None):
@@ -176,8 +182,8 @@ class Xray(AtlassianRestAPI):
             remove = []
         if add is None:
             add = []
-        update = {'add': add, 'remove': remove}
-        url = 'rest/raven/1.0/api/precondition/{0}/test'.format(precondition_key)
+        update = {"add": add, "remove": remove}
+        url = "rest/raven/1.0/api/precondition/{0}/test".format(precondition_key)
         return self.post(url, update)
 
     def delete_test_from_precondition(self, precondition_key, test_key):
@@ -187,7 +193,9 @@ class Xray(AtlassianRestAPI):
         :param test_key: Test Key which should no longer be associate with the pre-condition (eg. 'TEST-100')
         :return:
         """
-        url = 'rest/raven/1.0/api/precondition/{0}/test/{1}'.format(precondition_key, test_key)
+        url = "rest/raven/1.0/api/precondition/{0}/test/{1}".format(
+            precondition_key, test_key
+        )
         return self.delete(url)
 
     # Test Set API
@@ -199,13 +207,13 @@ class Xray(AtlassianRestAPI):
         :param page: OPTIONAL: Number of the page to be returned.
         :return: Return a list of the test associated with the test set.
         """
-        url = 'rest/raven/1.0/api/testset/{0}/test'.format(test_set_key)
+        url = "rest/raven/1.0/api/testset/{0}/test".format(test_set_key)
         params = {}
 
         if limit:
-            params['limit'] = limit
+            params["limit"] = limit
         if page:
-            params['page'] = page
+            params["page"] = page
 
         return self.get(url, params=params)
 
@@ -221,8 +229,8 @@ class Xray(AtlassianRestAPI):
             add = []
         if remove is None:
             remove = []
-        update = {'add': add, 'remove': remove}
-        url = 'rest/raven/1.0/api/testset/{0}/test'.format(test_set_key)
+        update = {"add": add, "remove": remove}
+        url = "rest/raven/1.0/api/testset/{0}/test".format(test_set_key)
         return self.post(url, update)
 
     def delete_test_from_test_set(self, test_set_key, test_key):
@@ -232,7 +240,7 @@ class Xray(AtlassianRestAPI):
         :param test_key: Test Key which should no longer be associate with the test set (eg. 'TEST-100')
         :return:
         """
-        url = 'rest/raven/1.0/api/testset/{0}/test/{1}'.format(test_set_key, test_key)
+        url = "rest/raven/1.0/api/testset/{0}/test/{1}".format(test_set_key, test_key)
         return self.delete(url)
 
     # Test Plans API
@@ -242,7 +250,7 @@ class Xray(AtlassianRestAPI):
         :param test_plan_key: Test set key (eg. 'PLAN-001').
         :return: Return a list of the test associated with the test plan.
         """
-        url = 'rest/raven/1.0/api/testplan/{0}/test'.format(test_plan_key)
+        url = "rest/raven/1.0/api/testplan/{0}/test".format(test_plan_key)
         return self.get(url)
 
     def update_test_plan(self, test_plan_key, add=None, remove=None):
@@ -257,8 +265,8 @@ class Xray(AtlassianRestAPI):
             add = []
         if remove is None:
             remove = []
-        update = {'add': add, 'remove': remove}
-        url = 'rest/raven/1.0/api/testplan/{0}/test'.format(test_plan_key)
+        update = {"add": add, "remove": remove}
+        url = "rest/raven/1.0/api/testplan/{0}/test".format(test_plan_key)
         return self.post(url, update)
 
     def delete_test_from_test_plan(self, test_plan_key, test_key):
@@ -268,11 +276,13 @@ class Xray(AtlassianRestAPI):
         :param test_key: Test Key which should no longer be associate with the test plan (eg. 'TEST-100')
         :return:
         """
-        url = 'rest/raven/1.0/api/testplan/{0}/test/{1}'.format(test_plan_key, test_key)
+        url = "rest/raven/1.0/api/testplan/{0}/test/{1}".format(test_plan_key, test_key)
         return self.delete(url)
 
     # Test Executions API
-    def get_tests_with_test_execution(self, test_exec_key, detailed=False, limit=None, page=None):
+    def get_tests_with_test_execution(
+        self, test_exec_key, detailed=False, limit=None, page=None
+    ):
         """
         Retrieve the tests associated with the given test execution.
         :param test_exec_key: Test execution key (eg. 'EXEC-001').
@@ -281,15 +291,15 @@ class Xray(AtlassianRestAPI):
         :param page: OPTIONAL: Number of the page to be returned.
         :return: Return a list of the test associated with the test execution.
         """
-        url = 'rest/raven/1.0/api/testexec/{0}/test'.format(test_exec_key)
+        url = "rest/raven/1.0/api/testexec/{0}/test".format(test_exec_key)
         params = {}
 
         if detailed:
-            params['detailed'] = detailed
+            params["detailed"] = detailed
         if limit:
-            params['limit'] = limit
+            params["limit"] = limit
         if page:
-            params['page'] = page
+            params["page"] = page
 
         return self.get(url, params=params)
 
@@ -298,15 +308,16 @@ class Xray(AtlassianRestAPI):
         Associate tests with the given test execution.
         :param test_exec_key: Test execution key (eg. 'EXEC-001').
         :param add: OPTIONAL: List of Test Keys to associate with the test execution (eg. ['TEST-2', 'TEST-3'])
-        :param remove: OPTIONAL: List of Test Keys no longer associate with the test execution (eg. ['TEST-4', 'TEST-5'])
+        :param remove: OPTIONAL:
+            List of Test Keys no longer associate with the test execution (eg. ['TEST-4', 'TEST-5'])
         :return:
         """
         if add is None:
             add = []
         if remove is None:
             remove = []
-        update = {'add': add, 'remove': remove}
-        url = 'rest/raven/1.0/api/testexec/{0}/test'.format(test_exec_key)
+        update = {"add": add, "remove": remove}
+        url = "rest/raven/1.0/api/testexec/{0}/test".format(test_exec_key)
         return self.post(url, update)
 
     def delete_test_from_test_execution(self, test_exec_key, test_key):
@@ -316,7 +327,7 @@ class Xray(AtlassianRestAPI):
         :param test_key: Test Key which should no longer be associate with the test execution (eg. 'TEST-100')
         :return:
         """
-        url = 'rest/raven/1.0/api/testexec/{0}/test/{1}'.format(test_exec_key, test_key)
+        url = "rest/raven/1.0/api/testexec/{0}/test/{1}".format(test_exec_key, test_key)
         return self.delete(url)
 
     # Test Runs API
@@ -326,7 +337,7 @@ class Xray(AtlassianRestAPI):
         :param test_run_id: ID of the test run (eg. 100).
         :return: Returns detailed information about the test run.
         """
-        url = 'rest/raven/1.0/api/testrun/{0}'.format(test_run_id)
+        url = "rest/raven/1.0/api/testrun/{0}".format(test_run_id)
         return self.get(url)
 
     def get_test_run_assignee(self, test_run_id):
@@ -335,7 +346,7 @@ class Xray(AtlassianRestAPI):
         :param test_run_id: ID of the test run (eg. 100).
         :return: Returns the assignee for the given test run
         """
-        url = 'rest/raven/1.0/api/testrun/{0}/assignee'.format(test_run_id)
+        url = "rest/raven/1.0/api/testrun/{0}/assignee".format(test_run_id)
         return self.get(url)
 
     def update_test_run_assignee(self, test_run_id, assignee):
@@ -343,10 +354,10 @@ class Xray(AtlassianRestAPI):
         Update the assignee for the given test run.
         :param test_run_id: ID of the test run (eg. 100).
         :param assignee: Assignee id (eg. 'bob')
-        :return: 
+        :return:
         """
-        update = {'assignee': assignee}
-        url = 'rest/raven/1.0/api/testrun/{0}'.format(test_run_id)
+        update = {"assignee": assignee}
+        url = "rest/raven/1.0/api/testrun/{0}".format(test_run_id)
         return self.put(url, update)
 
     def get_test_run_status(self, test_run_id):
@@ -355,7 +366,7 @@ class Xray(AtlassianRestAPI):
         :param test_run_id: ID of the test run (eg. 100).
         :return: Returns the status for the given test run
         """
-        url = 'rest/raven/1.0/api/testrun/{0}/status'.format(test_run_id)
+        url = "rest/raven/1.0/api/testrun/{0}/status".format(test_run_id)
         return self.get(url)
 
     def update_test_run_status(self, test_run_id, status):
@@ -363,10 +374,10 @@ class Xray(AtlassianRestAPI):
         Update the status for the given test run.
         :param test_run_id: ID of the test run (eg. 100).
         :param status: Status id (eg. 'PASS')
-        :return: 
+        :return:
         """
-        update = {'status': status}
-        url = 'rest/raven/1.0/api/testrun/{0}'.format(test_run_id)
+        update = {"status": status}
+        url = "rest/raven/1.0/api/testrun/{0}".format(test_run_id)
         return self.put(url, update)
 
     def get_test_run_defects(self, test_run_id):
@@ -375,7 +386,7 @@ class Xray(AtlassianRestAPI):
         :param test_run_id: ID of the test run (eg. 100).
         :return: Returns a list of defects for the given test run
         """
-        url = 'rest/raven/1.0/api/testrun/{0}/defect'.format(test_run_id)
+        url = "rest/raven/1.0/api/testrun/{0}/defect".format(test_run_id)
         return self.get(url)
 
     def update_test_run_defects(self, test_run_id, add=None, remove=None):
@@ -384,14 +395,14 @@ class Xray(AtlassianRestAPI):
         :param test_run_id: ID of the test run (eg. 100).
         :param add: OPTIONAL: List of defects to associate to the test run (eg. ['BUG-001', 'BUG-002'])
         :param remove: OPTIONAL: List of defects which no longer need to be associated to the test run (eg. ['BUG-003'])
-        :return: 
+        :return:
         """
         if add is None:
             add = []
         if remove is None:
             remove = []
-        update = {'defects': {'add': add, 'remove': remove}}
-        url = 'rest/raven/1.0/api/testrun/{0}'.format(test_run_id)
+        update = {"defects": {"add": add, "remove": remove}}
+        url = "rest/raven/1.0/api/testrun/{0}".format(test_run_id)
         return self.put(url, update)
 
     def get_test_run_comment(self, test_run_id):
@@ -400,7 +411,7 @@ class Xray(AtlassianRestAPI):
         :param test_run_id: ID of the test run (eg. 100).
         :return: Returns the comment for the given test run
         """
-        url = 'rest/raven/1.0/api/testrun/{0}/comment'.format(test_run_id)
+        url = "rest/raven/1.0/api/testrun/{0}/comment".format(test_run_id)
         return self.get(url)
 
     def update_test_run_comment(self, test_run_id, comment):
@@ -408,10 +419,10 @@ class Xray(AtlassianRestAPI):
         Update the comment for the given test run.
         :param test_run_id: ID of the test run (eg. 100).
         :param comment: Comment (eg. 'Test needs to be reworked')
-        :return: 
+        :return:
         """
-        update = {'comment': comment}
-        url = 'rest/raven/1.0/api/testrun/{0}'.format(test_run_id)
+        update = {"comment": comment}
+        url = "rest/raven/1.0/api/testrun/{0}".format(test_run_id)
         return self.put(url, update)
 
     def get_test_run_steps(self, test_run_id):
@@ -420,5 +431,5 @@ class Xray(AtlassianRestAPI):
         :param test_run_id: ID of the test run (eg. 100).
         :return: Returns the steps for the given test run
         """
-        url = 'rest/raven/1.0/api/testrun/{0}/step'.format(test_run_id)
+        url = "rest/raven/1.0/api/testrun/{0}/step".format(test_run_id)
         return self.get(url)
